package main;

# This is a stub package of Sub::Exporter. See Build.PL for more
# notes.
$main::INC_SUB_EXPORTER = $main::INC_SUB_EXPORTER = 1;

1;
